@@ -25,92 +25,79 @@ class CreateNodeRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Dds', '2015-12-01', 'CreateNode','dds')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_NodeType(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_NodeType(self): # String
 		return self.get_query_params().get('NodeType')
 
-	def set_NodeType(self,NodeType):
-		self.add_query_param('NodeType',NodeType)
-
-	def get_ClientToken(self):
+	def set_NodeType(self, NodeType):  # String
+		self.add_query_param('NodeType', NodeType)
+	def get_ClientToken(self): # String
 		return self.get_query_params().get('ClientToken')
 
-	def set_ClientToken(self,ClientToken):
-		self.add_query_param('ClientToken',ClientToken)
-
-	def get_ReadonlyReplicas(self):
+	def set_ClientToken(self, ClientToken):  # String
+		self.add_query_param('ClientToken', ClientToken)
+	def get_ReadonlyReplicas(self): # Integer
 		return self.get_query_params().get('ReadonlyReplicas')
 
-	def set_ReadonlyReplicas(self,ReadonlyReplicas):
-		self.add_query_param('ReadonlyReplicas',ReadonlyReplicas)
-
-	def get_CouponNo(self):
+	def set_ReadonlyReplicas(self, ReadonlyReplicas):  # Integer
+		self.add_query_param('ReadonlyReplicas', ReadonlyReplicas)
+	def get_CouponNo(self): # String
 		return self.get_query_params().get('CouponNo')
 
-	def set_CouponNo(self,CouponNo):
-		self.add_query_param('CouponNo',CouponNo)
-
-	def get_NodeClass(self):
+	def set_CouponNo(self, CouponNo):  # String
+		self.add_query_param('CouponNo', CouponNo)
+	def get_NodeClass(self): # String
 		return self.get_query_params().get('NodeClass')
 
-	def set_NodeClass(self,NodeClass):
-		self.add_query_param('NodeClass',NodeClass)
-
-	def get_SecurityToken(self):
+	def set_NodeClass(self, NodeClass):  # String
+		self.add_query_param('NodeClass', NodeClass)
+	def get_SecurityToken(self): # String
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
-	def get_DBInstanceId(self):
+	def set_SecurityToken(self, SecurityToken):  # String
+		self.add_query_param('SecurityToken', SecurityToken)
+	def get_DBInstanceId(self): # String
 		return self.get_query_params().get('DBInstanceId')
 
-	def set_DBInstanceId(self,DBInstanceId):
-		self.add_query_param('DBInstanceId',DBInstanceId)
-
-	def get_BusinessInfo(self):
+	def set_DBInstanceId(self, DBInstanceId):  # String
+		self.add_query_param('DBInstanceId', DBInstanceId)
+	def get_BusinessInfo(self): # String
 		return self.get_query_params().get('BusinessInfo')
 
-	def set_BusinessInfo(self,BusinessInfo):
-		self.add_query_param('BusinessInfo',BusinessInfo)
-
-	def get_AutoPay(self):
+	def set_BusinessInfo(self, BusinessInfo):  # String
+		self.add_query_param('BusinessInfo', BusinessInfo)
+	def get_AutoPay(self): # Boolean
 		return self.get_query_params().get('AutoPay')
 
-	def set_AutoPay(self,AutoPay):
-		self.add_query_param('AutoPay',AutoPay)
-
-	def get_ResourceOwnerAccount(self):
+	def set_AutoPay(self, AutoPay):  # Boolean
+		self.add_query_param('AutoPay', AutoPay)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_NodeStorage(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_NodeStorage(self): # Integer
 		return self.get_query_params().get('NodeStorage')
 
-	def set_NodeStorage(self,NodeStorage):
-		self.add_query_param('NodeStorage',NodeStorage)
-
-	def get_OwnerAccount(self):
+	def set_NodeStorage(self, NodeStorage):  # Integer
+		self.add_query_param('NodeStorage', NodeStorage)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OwnerId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
