@@ -25,74 +25,64 @@ class ModifyBackupPolicyRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Dds', '2015-12-01', 'ModifyBackupPolicy','dds')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_SecurityToken(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_SecurityToken(self): # String
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
-	def get_DBInstanceId(self):
+	def set_SecurityToken(self, SecurityToken):  # String
+		self.add_query_param('SecurityToken', SecurityToken)
+	def get_DBInstanceId(self): # String
 		return self.get_query_params().get('DBInstanceId')
 
-	def set_DBInstanceId(self,DBInstanceId):
-		self.add_query_param('DBInstanceId',DBInstanceId)
-
-	def get_EnableBackupLog(self):
+	def set_DBInstanceId(self, DBInstanceId):  # String
+		self.add_query_param('DBInstanceId', DBInstanceId)
+	def get_EnableBackupLog(self): # Long
 		return self.get_query_params().get('EnableBackupLog')
 
-	def set_EnableBackupLog(self,EnableBackupLog):
-		self.add_query_param('EnableBackupLog',EnableBackupLog)
-
-	def get_PreferredBackupPeriod(self):
+	def set_EnableBackupLog(self, EnableBackupLog):  # Long
+		self.add_query_param('EnableBackupLog', EnableBackupLog)
+	def get_PreferredBackupPeriod(self): # String
 		return self.get_query_params().get('PreferredBackupPeriod')
 
-	def set_PreferredBackupPeriod(self,PreferredBackupPeriod):
-		self.add_query_param('PreferredBackupPeriod',PreferredBackupPeriod)
-
-	def get_ResourceOwnerAccount(self):
+	def set_PreferredBackupPeriod(self, PreferredBackupPeriod):  # String
+		self.add_query_param('PreferredBackupPeriod', PreferredBackupPeriod)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OwnerId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_PreferredBackupTime(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_PreferredBackupTime(self): # String
 		return self.get_query_params().get('PreferredBackupTime')
 
-	def set_PreferredBackupTime(self,PreferredBackupTime):
-		self.add_query_param('PreferredBackupTime',PreferredBackupTime)
-
-	def get_BackupRetentionPeriod(self):
+	def set_PreferredBackupTime(self, PreferredBackupTime):  # String
+		self.add_query_param('PreferredBackupTime', PreferredBackupTime)
+	def get_BackupRetentionPeriod(self): # Long
 		return self.get_query_params().get('BackupRetentionPeriod')
 
-	def set_BackupRetentionPeriod(self,BackupRetentionPeriod):
-		self.add_query_param('BackupRetentionPeriod',BackupRetentionPeriod)
-
-	def get_LogBackupRetentionPeriod(self):
+	def set_BackupRetentionPeriod(self, BackupRetentionPeriod):  # Long
+		self.add_query_param('BackupRetentionPeriod', BackupRetentionPeriod)
+	def get_LogBackupRetentionPeriod(self): # Long
 		return self.get_query_params().get('LogBackupRetentionPeriod')
 
-	def set_LogBackupRetentionPeriod(self,LogBackupRetentionPeriod):
-		self.add_query_param('LogBackupRetentionPeriod',LogBackupRetentionPeriod)
\ No newline at end of file
+	def set_LogBackupRetentionPeriod(self, LogBackupRetentionPeriod):  # Long
+		self.add_query_param('LogBackupRetentionPeriod', LogBackupRetentionPeriod)
