@@ -23,70 +23,61 @@ from aliyunsdkdds.endpoint import endpoint_data
 class ModifyDBInstanceTDERequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Dds', '2015-12-01', 'ModifyDBInstanceTDE')
+		RpcRequest.__init__(self, 'Dds', '2015-12-01', 'ModifyDBInstanceTDE','dds')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_SecurityToken(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_SecurityToken(self): # String
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
-	def get_DBInstanceId(self):
+	def set_SecurityToken(self, SecurityToken):  # String
+		self.add_query_param('SecurityToken', SecurityToken)
+	def get_DBInstanceId(self): # String
 		return self.get_query_params().get('DBInstanceId')
 
-	def set_DBInstanceId(self,DBInstanceId):
-		self.add_query_param('DBInstanceId',DBInstanceId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_DBInstanceId(self, DBInstanceId):  # String
+		self.add_query_param('DBInstanceId', DBInstanceId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_EncryptionKey(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_EncryptionKey(self): # String
 		return self.get_query_params().get('EncryptionKey')
 
-	def set_EncryptionKey(self,EncryptionKey):
-		self.add_query_param('EncryptionKey',EncryptionKey)
-
-	def get_OwnerId(self):
+	def set_EncryptionKey(self, EncryptionKey):  # String
+		self.add_query_param('EncryptionKey', EncryptionKey)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_EncryptorName(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_EncryptorName(self): # String
 		return self.get_query_params().get('EncryptorName')
 
-	def set_EncryptorName(self,EncryptorName):
-		self.add_query_param('EncryptorName',EncryptorName)
-
-	def get_RoleARN(self):
+	def set_EncryptorName(self, EncryptorName):  # String
+		self.add_query_param('EncryptorName', EncryptorName)
+	def get_RoleARN(self): # String
 		return self.get_query_params().get('RoleARN')
 
-	def set_RoleARN(self,RoleARN):
-		self.add_query_param('RoleARN',RoleARN)
-
-	def get_TDEStatus(self):
+	def set_RoleARN(self, RoleARN):  # String
+		self.add_query_param('RoleARN', RoleARN)
+	def get_TDEStatus(self): # String
 		return self.get_query_params().get('TDEStatus')
 
-	def set_TDEStatus(self,TDEStatus):
-		self.add_query_param('TDEStatus',TDEStatus)
\ No newline at end of file
+	def set_TDEStatus(self, TDEStatus):  # String
+		self.add_query_param('TDEStatus', TDEStatus)
