@@ -23,70 +23,61 @@ from aliyunsdkdds.endpoint import endpoint_data
 class ModifySecurityIpsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Dds', '2015-12-01', 'ModifySecurityIps')
+		RpcRequest.__init__(self, 'Dds', '2015-12-01', 'ModifySecurityIps','dds')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_SecurityIps(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_SecurityIps(self): # String
 		return self.get_query_params().get('SecurityIps')
 
-	def set_SecurityIps(self,SecurityIps):
-		self.add_query_param('SecurityIps',SecurityIps)
-
-	def get_SecurityIpGroupName(self):
+	def set_SecurityIps(self, SecurityIps):  # String
+		self.add_query_param('SecurityIps', SecurityIps)
+	def get_SecurityIpGroupName(self): # String
 		return self.get_query_params().get('SecurityIpGroupName')
 
-	def set_SecurityIpGroupName(self,SecurityIpGroupName):
-		self.add_query_param('SecurityIpGroupName',SecurityIpGroupName)
-
-	def get_SecurityToken(self):
+	def set_SecurityIpGroupName(self, SecurityIpGroupName):  # String
+		self.add_query_param('SecurityIpGroupName', SecurityIpGroupName)
+	def get_SecurityToken(self): # String
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
-	def get_DBInstanceId(self):
+	def set_SecurityToken(self, SecurityToken):  # String
+		self.add_query_param('SecurityToken', SecurityToken)
+	def get_DBInstanceId(self): # String
 		return self.get_query_params().get('DBInstanceId')
 
-	def set_DBInstanceId(self,DBInstanceId):
-		self.add_query_param('DBInstanceId',DBInstanceId)
-
-	def get_ModifyMode(self):
+	def set_DBInstanceId(self, DBInstanceId):  # String
+		self.add_query_param('DBInstanceId', DBInstanceId)
+	def get_ModifyMode(self): # String
 		return self.get_query_params().get('ModifyMode')
 
-	def set_ModifyMode(self,ModifyMode):
-		self.add_query_param('ModifyMode',ModifyMode)
-
-	def get_ResourceOwnerAccount(self):
+	def set_ModifyMode(self, ModifyMode):  # String
+		self.add_query_param('ModifyMode', ModifyMode)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OwnerId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_SecurityIpGroupAttribute(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_SecurityIpGroupAttribute(self): # String
 		return self.get_query_params().get('SecurityIpGroupAttribute')
 
-	def set_SecurityIpGroupAttribute(self,SecurityIpGroupAttribute):
-		self.add_query_param('SecurityIpGroupAttribute',SecurityIpGroupAttribute)
\ No newline at end of file
+	def set_SecurityIpGroupAttribute(self, SecurityIpGroupAttribute):  # String
+		self.add_query_param('SecurityIpGroupAttribute', SecurityIpGroupAttribute)
